changeset 8985:8abc99ed5d93

[gaim-migrate @ 9760] Well... I feel like this should fix the ICQ HTML problems in 0.77. I thought this was how it was for 0.76 though, and I remember that havne't some silly minor problem. We'll see. Lemme know if you're seeing HTML tags when people IM you, or if other people are seeing HTML tags when you IM them. committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Thu, 20 May 2004 03:11:52 +0000
parents 4623d24347d8
children 8cf32769ba1b
files src/protocols/oscar/oscar.c
diffstat 1 files changed, 6 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/src/protocols/oscar/oscar.c	Thu May 20 02:24:17 2004 +0000
+++ b/src/protocols/oscar/oscar.c	Thu May 20 03:11:52 2004 +0000
@@ -3087,14 +3087,11 @@
 	}
 
 	/*
 	 * If the message is being sent to an ICQ user then escape any HTML,
 	 * because HTML should not be sent over ICQ as a means to format a message.
-	 * SIM is the only client we know of that sends HTML, everything else
-	 * (ie. official clients) use RTF.  Please let us know if this is
-	 * incorrect.
 	 */
 	if (isdigit(gaim_account_get_username(account)[0])) {
-		gchar *tmp2 = gaim_escape_html(tmp);
+		gchar *tmp2 = gaim_markup_strip_html(tmp);
 		g_free(tmp);
 		tmp = tmp2;
 	}
@@ -5151,8 +5148,10 @@
 
 		args.destsn = name;
 
-		/* For ICQ send newlines as CR/LF, for AIM send newlines as <BR> */
-		/* Also strip HTML for ICQ */
+		/*
+		 * If we're IMing an ICQ user then send newlines as CR/LF and
+		 * strip all HTML
+		 */
 		if (isdigit(name[0])) {
 			tmpmsg2 = gaim_markup_strip_html(message);
 			tmpmsg = gaim_str_add_cr(tmpmsg2);
@@ -3087,14 +3087,11 @@
 
 	/*
-	 * If the message is being sent to an ICQ user then escape any HTML,
+	 * If the message is being sent to an ICQ user then strip any HTML,
 	 * because HTML should not be sent over ICQ as a means to format a message.